==> jcodemodel-2.8.6-sources.jar: com/helger/jcodemodel/util/JCNameUtilities.java <==
/**
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 * Portions Copyright 2013-2016 Philip Helger + contributors
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.helger.jcodemodel.util;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Nonnull;

/**
 * @author Ben Fagin
 * @version 2013-04-01
 */
public final class JCNameUtilities
{
  private JCNameUtilities ()
  {}

  @Nonnull
  public static String getFullName (@Nonnull final Class <?> aClass)
  {
    if (aClass == null)
      throw new IllegalArgumentException ("class cannot be null");

    final StringBuilder name = new StringBuilder ();
    // Package name
    name.append (aClass.getPackage ().getName ()).append ('.');

    // Get all enclosing classes
    Class <?> klaus = aClass;
    final List <Class <?>> enclosingClasses = new ArrayList <Class <?>> ();
    while ((klaus = klaus.getEnclosingClass ()) != null)
      enclosingClasses.add (klaus);

    // Back to front
    for (int i = enclosingClasses.size () - 1; i >= 0; i--)
      name.append (enclosingClasses.get (i).getSimpleName ()).append ('.');

    // Append main class name
    name.append (aClass.getSimpleName ());
    return name.toString ();
  }
}

==> jcodemodel-3.4.1-sources.jar: com/helger/jcodemodel/util/JCNameUtilities.java <==
/**
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 * Portions Copyright 2013-2020 Philip Helger + contributors
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.helger.jcodemodel.util;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Nonnull;

/**
 * @author Ben Fagin
 * @version 2013-04-01
 */
public final class JCNameUtilities
{
  private JCNameUtilities ()
  {}

  @Nonnull
  public static String getFullName (@Nonnull final Class <?> aClass)
  {
    JCValueEnforcer.notNull (aClass, "Class");

    final StringBuilder name = new StringBuilder ();

    // Package name
    // null on Java 8
    // Empty name on Java 11
    if (aClass.getPackage () != null && aClass.getPackage ().getName ().length () > 0)
      name.append (aClass.getPackage ().getName ()).append ('.');

    // Get all enclosing classes
    Class <?> klaus = aClass;
    final List <Class <?>> enclosingClasses = new ArrayList <> ();
    while ((klaus = klaus.getEnclosingClass ()) != null)
      enclosingClasses.add (klaus);

    // Back to front
    for (int i = enclosingClasses.size () - 1; i >= 0; i--)
      name.append (enclosingClasses.get (i).getSimpleName ()).append ('.');

    // Append main class name
    name.append (aClass.getSimpleName ());
    return name.toString ();
  }
}
